/*
 *	vii - buffer and display outout
 *	Copyright (C) 1991, 1995, 1999, 2005 Peter Miller
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 *
 * MANIFEST: operating system entry point
 */

#include <ac/stdio.h>
#include <ac/stdlib.h>
#include <ac/unistd.h>

#include <arglex.h>
#include <error.h>
#include <help.h>
#include <option.h>
#include <str.h>
#include <term.h>
#include <veneer.h>
#include <version.h>

enum
{
	arglex_token_execute,
	arglex_token_terminal,
	arglex_token_interval,
};

static arglex_table_ty argtab[] =
{
	{ "-Execute",	arglex_token_execute,	},
	{ "-Terminal",	arglex_token_terminal,	},
	{ "-Interval",	arglex_token_interval,	},
	{ 0, }	/* end marker */
};


static void usage _((void));

static void
usage()
{
	char		*progname;

	progname = option_progname_get();
	fprintf(stderr, "usage: %s [ <option>... ]\n", progname);
	fprintf(stderr, "       %s -Help\n", progname);
	exit(1);
}


static void main_help _((void));

static void
main_help()
{
	static char *text[] =
	{
#include <../man1/vii.h>
	};

	help(text, SIZEOF(text), usage);
}


int main _((int, char **));

int
main(argc, argv)
	int	argc;
	char	**argv;
{
	char	*command	= 0;

	arglex_init(argc, argv, argtab);
	str_initialize();
	switch (arglex())
	{
	case arglex_token_help:
		main_help();
		exit(0);
		return 0;

	case arglex_token_version:
		version();
		exit(0);
		return 0;

	default:
		break;
	}

	while (arglex_token != arglex_token_eoln)
	{
		switch (arglex_token)
		{
		default:
			error("misplaced \"%s\" argument", arglex_value.alv_string);
			usage();

		case arglex_token_execute:
			if (arglex() != arglex_token_string)
				usage();
			if (command)
				fatal("too many commands specified");
			command = arglex_value.alv_string;
			break;

		case arglex_token_terminal:
			if (arglex() != arglex_token_string)
				usage();
			if (terminal)
				fatal("too many terminal types specified");
			terminal = arglex_value.alv_string;
			break;

		case arglex_token_interval:
			if (arglex() != arglex_token_number)
				usage();
			sleep_time = arglex_value.alv_number;
			if (sleep_time < 1)
				fatal("interval must be 1 or more seconds");
			break;
		}
		arglex();
	}
	if (!command && isatty(0))
		fatal("can't take input from a terminal");

	veneer(command);
	exit(0);
	return 0;
}
